@@ -1,10 +1,32 @@
 import typing
+from importlib import import_module
+from importlib.util import find_spec
 
-import importlib.util
+from typing_extensions import Literal
 
 from .order import Order
 
 
+@typing.overload
+def choice_in_order(
+    module_names: typing.List[str],
+    order: Order = Order.TO_RIGHT,
+    do_import: Literal[True] = ...,
+    default: typing.Optional[str] = None,
+) -> typing.Any:
+    ...
+
+
+@typing.overload
+def choice_in_order(
+    module_names: typing.List[str],
+    order: Order = Order.TO_RIGHT,
+    do_import: Literal[False] = ...,
+    default: typing.Optional[str] = None,
+) -> str:
+    ...
+
+
 def choice_in_order(
     module_names: typing.List[str],
     order: Order = Order.TO_RIGHT,
@@ -22,7 +44,7 @@ def choice_in_order(
     installed = [
         module_name
         for module_name in module_names
-        if importlib.util.find_spec(module_name) is not None
+        if find_spec(module_name) is not None
     ]
     if not installed and default is None:
         raise ModuleNotFoundError(
@@ -31,4 +53,4 @@ def choice_in_order(
         )
 
     ordered_module_name = installed[order.value] if installed else default_name
-    return ordered_module_name if not do_import else __import__(ordered_module_name)
+    return ordered_module_name if not do_import else import_module(ordered_module_name)
